@@ -69,7 +69,7 @@ class Hasher(object):
         self.tqdm_args.setdefault("unit_scale", True)
         self.tqdm_args.setdefault("unit_divisor", 1024)
 
-    def hash_f(self, filepath, start=None, stop=None):
+    def hash_file(self, filepath, start=None, stop=None):
         """Return the hash value of a file.
 
         Parameters
@@ -113,7 +113,7 @@ class Hasher(object):
             bar.update(remainsize)
         return ctx.digest()
 
-    def hash_d(self, dirpath, start=None, stop=None):
+    def hash_dir(self, dirpath, start=None, stop=None):
         """Return the hash value of a directory.
 
         Parameters
@@ -136,9 +136,9 @@ class Hasher(object):
         with os.scandir(dirpath) as it:
             for entry in it:
                 if entry.is_dir():
-                    other = self.hash_d(entry, start, stop)
+                    other = self.hash_dir(entry, start, stop)
                 else:
-                    other = self.hash_f(entry, start, stop)
+                    other = self.hash_file(entry, start, stop)
                 # Just XOR each byte string as hash value.
                 value = strxor(value, other)
         return value
@@ -165,9 +165,9 @@ class Hasher(object):
 
         if os.path.isdir(path):
             if dir_ok:
-                return self.hash_d(path, start, stop)
+                return self.hash_dir(path, start, stop)
             raise IsADirectory("'{}' is a directory".format(path))
-        return self.hash_f(path, start, stop)
+        return self.hash_file(path, start, stop)
 
     __call__ = hash
 
@@ -194,7 +194,7 @@ class HashFileReader(object):
         Returns
         -------
         hash_line : str
-            A line of *hash* and *filename* with GNU Coreutils style.
+            A line of *hash* and *name* with GNU Coreutils style.
         """
 
         while True:
@@ -208,50 +208,47 @@ class HashFileReader(object):
             break
         return line  # empty string for EOF
 
-    def read_hash_line_2(self):
-        hash_line = self.read_hash_line()
-        if hash_line:
-            return parse_hash_line(hash_line)
-        return None  # None for EOF
-
-    def read_hash_line_3(self, *, root=None):
-        result = self.read_hash_line_2()
-        if result:
-            hex_hash_value, path_repr = result
-            path = _parse_path_repr(path_repr, root=root)
-            return hex_hash_value, path
-        return None  # None for EOF
-
-    def iter(self, mode=3, **kwargs):
-        if mode == 1:
-            read = self.read_hash_line
-        elif mode == 2:
-            read = self.read_hash_line_2
-        elif mode == 3:
-            read = self.read_hash_line_3
-        else:
-            ValueError("mode must in {{1, 2, 3}}, got {}".format(mode))
+    def iter(self):
+        """Yield hash line."""
 
         with self:
             while True:
-                hash_line = read(**kwargs)
+                hash_line = self.read_hash_line()
                 if not hash_line:
                     break
                 yield hash_line
 
+    def iter2(self, *, root=None):
+        """Yield hash and name."""
+
+        for hash_line in self:
+            yield parse_hash_line(hash_line, root=root)
+
+    def iter3(self, *, root=None):
+        """Yield hash line, hash and name."""
+
+        for hash_line in self:
+            yield hash_line, *parse_hash_line(hash_line, root=root)
+
+    def iter_hash(self):
+        """Yield hash."""
+
+        for entry in self.iter2():
+            yield entry[0]
+
+    def iter_name(self, *, root=None):
+        """Yield name."""
+
+        for entry in self.iter2(root=root):
+            yield entry[1]
+
     def __enter__(self):
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
         self.close()
 
-    def __iter__(self):
-        with self as f:
-            while True:
-                hash_line = f.read_hash_line()
-                if not hash_line:
-                    break
-                yield hash_line
+    __iter__ = iter
 
 
 class HashFileWriter(object):
@@ -276,19 +273,11 @@ class HashFileWriter(object):
         Parameters
         ----------
         hash_line : str
-            A line of *hash* and *filename* with GNU Coreutils style.
+            A line of *hash* and *name* with GNU Coreutils style.
         """
 
         self.file.write(hash_line)
 
-    def write_hash_line_2(self, hex_hash_value, path_repr):
-        hash_line = format_hash_line(hex_hash_value, path_repr)
-        self.write_hash_line(hash_line)
-
-    def write_hash_line_3(self, hex_hash_value, path, *, root=None):
-        path_repr = _format_path_repr(path, root=root)
-        self.write_hash_line_2(hex_hash_value, path_repr)
-
     def write_comment(self, comment):
         """Write comment.
 
@@ -309,24 +298,27 @@ class HashFileWriter(object):
         self.close()
 
 
-def format_hash_line(hex_hash_value, path_repr):
+def format_hash_line(hex_hash_value, path, *, root=None):
     r"""Format hash line.
 
     Parameters
     ----------
     hex_hash_value : str
-        The hex hash value string.
-    path_repr : str or path-like
-        The certain path representation of a file or a directory with
-        corresponding hash value.
-        (1) A absolute path;
-        (2) A relative path;
-        (3) A path relative to a given root directory.
+        The hexadecimal hash value string.
+    path : str or path-like
+        The path of a file or a directory with corresponding hash value. Three
+        representations are supported:
+        (1) Absolute path;
+        (2) Relative path;
+        (3) Relative to a given root directory.
+    root : str, path-like or None, optional (default: None)
+        The root directory of `path`. The path field in `hash_line` is relative
+        to the root directory.
 
     Returns
     -------
     hash_line : str
-        A line of *hash* and *filename* with GNU Coreutils style.
+        A line of *hash* and *name* with GNU Coreutils style.
 
     Examples
     --------
@@ -334,27 +326,33 @@ def format_hash_line(hex_hash_value, path_repr):
     'd41d8cd98f00b204e9800998ecf8427e *a.txt\n'
     """
 
-    return "{} *{}\n".format(hex_hash_value, path_repr)
+    if root is not None:
+        path = os.path.relpath(path, root)
+    path = os.path.normpath(path)
+    return "{} *{}\n".format(hex_hash_value, path)
 
 
-def parse_hash_line(hash_line):
+def parse_hash_line(hash_line, *, root=None):
     r"""Parse hash line.
 
     Parameters
     ----------
     hash_line : str
-        A line of *hash* and *filename* with GNU Coreutils style.
+        A line of *hash* and *name* with GNU Coreutils style.
+    root : str, path-like or None, optional (default: None)
+        The root directory of `path`. The path field in `hash_line` is relative
+        to the root directory.
 
     Returns
     -------
     hex_hash_value : str
-        The hex hash value string.
-    path_repr : str
-        The certain path representation of a file or a directory with
-        corresponding hash value.
-        (1) A absolute path;
-        (2) A relative path;
-        (3) A path relative to a given root directory.
+        The hexadecimal hash value string.
+    path : str
+        The path of a file or a directory with corresponding hash value. Three
+        representations are supported:
+        (1) Absolute path;
+        (2) Relative path;
+        (3) Relative to a given root directory.
 
     Examples
     --------
@@ -365,19 +363,11 @@ def parse_hash_line(hash_line):
     m = _HASH_LINE_RE.match(hash_line)
     if m is None:
         raise ParseHashLineError(hash_line)
-    return m.groups()
-
-
-def _format_path_repr(path, *, root=None):
+    hex_hash_value, path = m.groups()
     if root is not None:
-        path = os.path.relpath(path, root)
-    return os.path.normpath(path)
-
-
-def _parse_path_repr(path_repr, *, root=None):
-    if root is not None:
-        path_repr = os.path.join(root, path_repr)
-    return os.path.normpath(path_repr)
+        path = os.path.join(root, path)
+    path = os.path.normpath(path)
+    return hex_hash_value, path
 
 
 def generate_hash_line(path, hash_function, *, root=None):
@@ -396,13 +386,12 @@ def generate_hash_line(path, hash_function, *, root=None):
     Returns
     -------
     hash_line : str
-        A line of *hash* and *filename* with GNU Coreutils style.
+        A line of *hash* and *name* with GNU Coreutils style.
     """
 
     hash_value = hash_function(path)
     hex_hash_value = hash_value.hex()
-    path_repr = _format_path_repr(path, root=root)
-    return format_hash_line(hex_hash_value, path_repr)
+    return format_hash_line(hex_hash_value, path, root=root)
 
 
 def check_hash_line(hash_line, hash_function, *, root=None):
@@ -411,7 +400,7 @@ def check_hash_line(hash_line, hash_function, *, root=None):
     Parameters
     ----------
     hash_line : str
-        A line of *hash* and *filename* with GNU Coreutils style.
+        A line of *hash* and *name* with GNU Coreutils style.
     hash_function : callable(str or path-like) -> bytes-like
         A function for generating hash value.
     root : str, path-like or None, optional (default: None)
@@ -424,9 +413,8 @@ def check_hash_line(hash_line, hash_function, *, root=None):
         The path of a file or a directory with corresponding hash value.
     """
 
-    hex_hash_value, path_repr = parse_hash_line(hash_line)
+    hex_hash_value, path = parse_hash_line(hash_line, root=root)
     hash_value = bytes.fromhex(hex_hash_value)
-    path = _parse_path_repr(path_repr, root=root)
     curr_hash_value = hash_function(path)
     if not compare_digest(hash_value, curr_hash_value):
         raise CheckHashLineError(hash_line, hash_value, path, curr_hash_value)
@@ -434,8 +422,7 @@ def check_hash_line(hash_line, hash_function, *, root=None):
 
 
 def _parse_for_re(hash_line, *, root=None):
-    hex_hash_value, path_repr = parse_hash_line(hash_line)
-    nameing_path = _parse_path_repr(path_repr, root=root)
+    hex_hash_value, nameing_path = parse_hash_line(hash_line, root=root)
     hashing_path = os.path.join(os.path.dirname(nameing_path), hex_hash_value)
     return hashing_path, nameing_path
 
@@ -446,7 +433,7 @@ def re_name_to_hash(hash_line, *, root=None):
     Parameters
     ----------
     hash_line : str
-        A line of *hash* and *filename* with GNU Coreutils style.
+        A line of *hash* and *name* with GNU Coreutils style.
     root : str, path-like or None, optional (default: None)
         The root directory of `path`. The path field in `hash_line` is relative
         to the root directory.
@@ -463,7 +450,7 @@ def re_hash_to_name(hash_line, *, root=None):
     Parameters
     ----------
     hash_line : str
-        A line of *hash* and *filename* with GNU Coreutils style.
+        A line of *hash* and *name* with GNU Coreutils style.
     root : str, path-like or None, optional (default: None)
         The root directory of `path`. The path field in `hash_line` is relative
         to the root directory.
